.. py:currentmodule:: rubin_scheduler.sim_archive

.. _sim-archive-api:

===============
sim_archive API
===============

.. automodule:: rubin_scheduler.sim_archive
    :imported-members:
    :members:
    :show-inheritance:
